/**
 * Specifies the direction of the ken burns effect.
 */
export declare const enum Direction {
    Normal = "normal",
    Reverse = "reverse",
    Random = "random",
}
export declare const animationNames: string[];
/**
 * `ken-burns-carousel`
 *
 * Displays a set of images in a smoothly-fading ken burns style carousel.
 *
 * @demo ../demo/index.html
 */
export default class KenBurnsCarousel extends HTMLElement {
    static readonly observedAttributes: string[];
    /**
     * Specifies the list of ken burns animations to apply to the elements.
     *
     * This allows customizing the built-in animations to your liking by overriding
     * the ones you don't like with custom CSS animations.
     *
     * This can also be set via setting the `animation-names`-attribute to a space-
     * separated list of CSS animation names.
     *
     * @type String[]
     */
    animationNames: string[];
    /**
     * The direction to play the animations in.
     *
     * Defaults to Direction.Random, meaning that with each image the associated ken
     * burns animation is either played forwards or backwards adding additional visual
     * diversity.
     *
     * This can also be set via the `animation-direction`-attribute.
     *
     * @type Direction
     */
    animationDirection: Direction;
    private _fadeDuration;
    private _imgList;
    private _slideDuration;
    private _timeout;
    private _wrapper;
    /**
     * The duration of the crossfading animation in millseconds.
     *
     * Must be smaller than the slide duration. Defaults to 2500ms.
     * This can also be set via the `fade-duration`-attribute.
     *
     * @type number
     */
    fadeDuration: number;
    /**
     * The list of URLs to the images to display.
     *
     * You can either set this property directly, or set a the `images`-attribute
     * to a space-separated list of URLs.
     *
     * @type string[]
     */
    images: string[];
    /**
     * The duration of the sliding (or ken burns) animation in millseconds.
     *
     * Must be greater than or equal to the fade duration. Defaults to 20s.
     * This can also be set via the `slide-duration`-attribute.
     *
     * @type number
     */
    slideDuration: number;
    constructor();
    attributeChangedCallback(name: string, oldVal: string, newVal: string): void;
    private animate(images);
}
